==> haskell-x11-xft-0.3.4-162-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   X11-xft
version:                0.3.4
visibility:             public
id:                     X11-xft-0.3.4-KonYOmZa9jhC3txZz4uoKU
key:                    X11-xft-0.3.4-KonYOmZa9jhC3txZz4uoKU
license:                BSD-3-Clause
maintainer:             xmonad@haskell.org
author:                 Clemens Fruhwirth
synopsis:               Bindings to the Xft and some Xrender parts
description:
    A Haskell bindings to the X Font library. With it, Haskell X11
    applications can access high quality font renderings and provide
    fonts with anti-aliasing and subpixel rendering. The bindings
    also provide minimal bindings to Xrender parts.

category:               Graphics
abi:                    ed9ebe7ece0e2b5e3408b96a0a0f229d
exposed:                True
exposed-modules:        Graphics.X11.Xft Graphics.X11.Xrender
import-dirs:            /usr/lib/ghc-9.4.8/site-local/X11-xft-0.3.4
library-dirs:           /usr/lib/ghc-9.4.8/site-local/X11-xft-0.3.4
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/X11-xft-0.3.4
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-x11-xft
hs-libraries:           HSX11-xft-0.3.4-KonYOmZa9jhC3txZz4uoKU
extra-libraries:        Xft
extra-libraries-static:
    Xft Xrender X11 pthread xcb Xau Xdmcp fontconfig m expat m freetype
    dl bz2 png16 m m z brotlidec brotlicommon

include-dirs:           /usr/include/freetype2 /usr/include/libpng16
depends:
    X11-1.10.3-296FmCDygJo4Xo4fAuEwJZ base-4.17.2.1
    utf8-string-1.0.2-4OrQf1vZkgOAJqnDO7nv41

haddock-interfaces:     /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html:           /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x11-xft-0.3.4-164-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x11-xft.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   X11-xft
version:                0.3.4
visibility:             public
id:                     X11-xft-0.3.4-KDDg7VHuM1h3G3OtpeQ0sv
key:                    X11-xft-0.3.4-KDDg7VHuM1h3G3OtpeQ0sv
license:                BSD-3-Clause
maintainer:             xmonad@haskell.org
author:                 Clemens Fruhwirth
synopsis:               Bindings to the Xft and some Xrender parts
description:
    A Haskell bindings to the X Font library. With it, Haskell X11
    applications can access high quality font renderings and provide
    fonts with anti-aliasing and subpixel rendering. The bindings
    also provide minimal bindings to Xrender parts.

category:               Graphics
abi:                    8720144c24fa7c5f0f7a7c792cfdda2a
exposed:                True
exposed-modules:        Graphics.X11.Xft Graphics.X11.Xrender
import-dirs:            /usr/lib/ghc-9.4.8/site-local/X11-xft-0.3.4
library-dirs:           /usr/lib/ghc-9.4.8/site-local/X11-xft-0.3.4
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/X11-xft-0.3.4
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-x11-xft
hs-libraries:           HSX11-xft-0.3.4-KDDg7VHuM1h3G3OtpeQ0sv
extra-libraries:        Xft
extra-libraries-static:
    Xft Xrender X11 pthread xcb Xau Xdmcp fontconfig m expat m freetype
    dl bz2 png16 m m z brotlidec brotlicommon

include-dirs:           /usr/include/freetype2 /usr/include/libpng16
depends:
    X11-1.10.3-296FmCDygJo4Xo4fAuEwJZ base-4.17.2.1
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:     /usr/share/doc/haskell-x11-xft/html/X11-xft.haddock
haddock-html:           /usr/share/doc/haskell-x11-xft/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
